from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from typing import List

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.v2025_r0.file_reference_v2025_r0 import FileReferenceV2025R0

from box_sdk_gen.schemas.v2025_r0.file_version_base_v2025_r0 import (
    FileVersionBaseV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.doc_gen_document_generation_data_v2025_r0 import (
    DocGenDocumentGenerationDataV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.doc_gen_job_v2025_r0 import DocGenJobV2025R0

from box_sdk_gen.schemas.v2025_r0.client_error_v2025_r0 import ClientErrorV2025R0

from box_sdk_gen.parameters.v2025_r0.box_version_header_v2025_r0 import (
    BoxVersionHeaderV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.doc_gen_jobs_full_v2025_r0 import (
    DocGenJobsFullV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.doc_gen_jobs_v2025_r0 import DocGenJobsV2025R0

from box_sdk_gen.schemas.v2025_r0.doc_gen_batch_base_v2025_r0 import (
    DocGenBatchBaseV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.doc_gen_batch_create_request_v2025_r0 import (
    DocGenBatchCreateRequestV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class CreateDocgenBatchV2025R0DestinationFolderTypeField(str, Enum):
    FOLDER = 'folder'


class CreateDocgenBatchV2025R0DestinationFolder(BaseObject):
    _discriminator = 'type', {'folder'}

    def __init__(
        self,
        id: str,
        *,
        type: CreateDocgenBatchV2025R0DestinationFolderTypeField = CreateDocgenBatchV2025R0DestinationFolderTypeField.FOLDER,
        **kwargs
    ):
        """
        :param id: ID of the folder.
        :type id: str
        :param type: The value will always be `folder`., defaults to CreateDocgenBatchV2025R0DestinationFolderTypeField.FOLDER
        :type type: CreateDocgenBatchV2025R0DestinationFolderTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class DocgenManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_docgen_job_by_id_v2025_r0(
        self,
        job_id: str,
        *,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> DocGenJobV2025R0:
        """
                Get details of the Box Doc Gen job.
                :param job_id: Box Doc Gen job ID.
        Example: 123
                :type job_id: str
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/docgen_jobs/',
                        to_string(job_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, DocGenJobV2025R0)

    def get_docgen_jobs_v2025_r0(
        self,
        *,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> DocGenJobsFullV2025R0:
        """
                Lists all Box Doc Gen jobs for a user.
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'marker': to_string(marker), 'limit': to_string(limit)}
        )
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/docgen_jobs']
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, DocGenJobsFullV2025R0)

    def get_docgen_batch_job_by_id_v2025_r0(
        self,
        batch_id: str,
        *,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> DocGenJobsV2025R0:
        """
                Lists Box Doc Gen jobs in a batch.
                :param batch_id: Box Doc Gen batch ID.
        Example: 123
                :type batch_id: str
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'marker': to_string(marker), 'limit': to_string(limit)}
        )
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/docgen_batch_jobs/',
                        to_string(batch_id),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, DocGenJobsV2025R0)

    def create_docgen_batch_v2025_r0(
        self,
        file: FileReferenceV2025R0,
        input_source: str,
        destination_folder: CreateDocgenBatchV2025R0DestinationFolder,
        output_type: str,
        document_generation_data: List[DocGenDocumentGenerationDataV2025R0],
        *,
        file_version: Optional[FileVersionBaseV2025R0] = None,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> DocGenBatchBaseV2025R0:
        """
        Generates a document using a Box Doc Gen template.
        :param input_source: Source of input. The value has to be `api` for all the API-based document generation requests.
        :type input_source: str
        :param output_type: Type of the output file.
        :type output_type: str
        :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
        :type box_version: BoxVersionHeaderV2025R0, optional
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'file': file,
            'file_version': file_version,
            'input_source': input_source,
            'destination_folder': destination_folder,
            'output_type': output_type,
            'document_generation_data': document_generation_data,
        }
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/docgen_batches']
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, DocGenBatchBaseV2025R0)



from enum import Enum

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.integration_mapping_partner_item_slack import (
    IntegrationMappingPartnerItemSlack,
)

from box_sdk_gen.schemas.integration_mapping_partner_item_teams_create_request import (
    IntegrationMappingPartnerItemTeamsCreateRequest,
)

from box_sdk_gen.schemas.integration_mappings import IntegrationMappings

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.integration_mapping import IntegrationMapping

from box_sdk_gen.schemas.integration_mapping_slack_create_request import (
    IntegrationMappingSlackCreateRequest,
)

from box_sdk_gen.schemas.integration_mapping_box_item_slack import (
    IntegrationMappingBoxItemSlack,
)

from box_sdk_gen.schemas.integration_mapping_slack_options import (
    IntegrationMappingSlackOptions,
)

from box_sdk_gen.schemas.integration_mappings_teams import IntegrationMappingsTeams

from box_sdk_gen.schemas.integration_mapping_teams import IntegrationMappingTeams

from box_sdk_gen.schemas.integration_mapping_teams_create_request import (
    IntegrationMappingTeamsCreateRequest,
)

from box_sdk_gen.schemas.folder_reference import FolderReference

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class GetSlackIntegrationMappingPartnerItemType(str, Enum):
    CHANNEL = 'channel'


class GetSlackIntegrationMappingBoxItemType(str, Enum):
    FOLDER = 'folder'


class GetTeamsIntegrationMappingPartnerItemType(str, Enum):
    CHANNEL = 'channel'
    TEAM = 'team'


class GetTeamsIntegrationMappingBoxItemType(str, Enum):
    FOLDER = 'folder'


class IntegrationMappingsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_slack_integration_mapping(
        self,
        *,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        partner_item_type: Optional[GetSlackIntegrationMappingPartnerItemType] = None,
        partner_item_id: Optional[str] = None,
        box_item_id: Optional[str] = None,
        box_item_type: Optional[GetSlackIntegrationMappingBoxItemType] = None,
        is_manually_created: Optional[bool] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> IntegrationMappings:
        """
                Lists [Slack integration mappings](https://support.box.com/hc/en-us/articles/4415585987859-Box-as-the-Content-Layer-for-Slack) in a users' enterprise.

                You need Admin or Co-Admin role to


                use this endpoint.

                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param partner_item_type: Mapped item type, for which the mapping should be returned., defaults to None
                :type partner_item_type: Optional[GetSlackIntegrationMappingPartnerItemType], optional
                :param partner_item_id: ID of the mapped item,
        for which the mapping should be returned., defaults to None
                :type partner_item_id: Optional[str], optional
                :param box_item_id: Box item ID, for which the mappings should be returned., defaults to None
                :type box_item_id: Optional[str], optional
                :param box_item_type: Box item type, for
        which the mappings should be returned., defaults to None
                :type box_item_type: Optional[GetSlackIntegrationMappingBoxItemType], optional
                :param is_manually_created: Whether the mapping has been manually created., defaults to None
                :type is_manually_created: Optional[bool], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'marker': to_string(marker),
                'limit': to_string(limit),
                'partner_item_type': to_string(partner_item_type),
                'partner_item_id': to_string(partner_item_id),
                'box_item_id': to_string(box_item_id),
                'box_item_type': to_string(box_item_type),
                'is_manually_created': to_string(is_manually_created),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/integration_mappings/slack',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, IntegrationMappings)

    def create_slack_integration_mapping(
        self,
        partner_item: IntegrationMappingPartnerItemSlack,
        box_item: IntegrationMappingBoxItemSlack,
        *,
        options: Optional[IntegrationMappingSlackOptions] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> IntegrationMapping:
        """
        Creates a [Slack integration mapping](https://support.box.com/hc/en-us/articles/4415585987859-Box-as-the-Content-Layer-for-Slack)

        by mapping a Slack channel to a Box item.


        You need Admin or Co-Admin role to


        use this endpoint.

        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'partner_item': partner_item,
            'box_item': box_item,
            'options': options,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/integration_mappings/slack',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, IntegrationMapping)

    def update_slack_integration_mapping_by_id(
        self,
        integration_mapping_id: str,
        *,
        box_item: Optional[IntegrationMappingBoxItemSlack] = None,
        options: Optional[IntegrationMappingSlackOptions] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> IntegrationMapping:
        """
                Updates a [Slack integration mapping](https://support.box.com/hc/en-us/articles/4415585987859-Box-as-the-Content-Layer-for-Slack).

                Supports updating the Box folder ID and options.


                You need Admin or Co-Admin role to


                use this endpoint.

                :param integration_mapping_id: An ID of an integration mapping.
        Example: "11235432"
                :type integration_mapping_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'box_item': box_item, 'options': options}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/integration_mappings/slack/',
                        to_string(integration_mapping_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, IntegrationMapping)

    def delete_slack_integration_mapping_by_id(
        self,
        integration_mapping_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes a [Slack integration mapping](https://support.box.com/hc/en-us/articles/4415585987859-Box-as-the-Content-Layer-for-Slack).

                You need Admin or Co-Admin role to


                use this endpoint.

                :param integration_mapping_id: An ID of an integration mapping.
        Example: "11235432"
                :type integration_mapping_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/integration_mappings/slack/',
                        to_string(integration_mapping_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def get_teams_integration_mapping(
        self,
        *,
        partner_item_type: Optional[GetTeamsIntegrationMappingPartnerItemType] = None,
        partner_item_id: Optional[str] = None,
        box_item_id: Optional[str] = None,
        box_item_type: Optional[GetTeamsIntegrationMappingBoxItemType] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> IntegrationMappingsTeams:
        """
                Lists [Teams integration mappings](https://support.box.com/hc/en-us/articles/360044681474-Using-Box-for-Teams) in a users' enterprise.

                You need Admin or Co-Admin role to


                use this endpoint.

                :param partner_item_type: Mapped item type, for which the mapping should be returned., defaults to None
                :type partner_item_type: Optional[GetTeamsIntegrationMappingPartnerItemType], optional
                :param partner_item_id: ID of the mapped item,
        for which the mapping should be returned., defaults to None
                :type partner_item_id: Optional[str], optional
                :param box_item_id: Box item ID, for which the mappings should be returned., defaults to None
                :type box_item_id: Optional[str], optional
                :param box_item_type: Box item type, for
        which the mappings should be returned., defaults to None
                :type box_item_type: Optional[GetTeamsIntegrationMappingBoxItemType], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'partner_item_type': to_string(partner_item_type),
                'partner_item_id': to_string(partner_item_id),
                'box_item_id': to_string(box_item_id),
                'box_item_type': to_string(box_item_type),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/integration_mappings/teams',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, IntegrationMappingsTeams)

    def create_teams_integration_mapping(
        self,
        partner_item: IntegrationMappingPartnerItemTeamsCreateRequest,
        box_item: FolderReference,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> IntegrationMappingTeams:
        """
        Creates a [Teams integration mapping](https://support.box.com/hc/en-us/articles/360044681474-Using-Box-for-Teams)

        by mapping a Teams channel to a Box item.


        You need Admin or Co-Admin role to


        use this endpoint.

        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'partner_item': partner_item, 'box_item': box_item}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/integration_mappings/teams',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, IntegrationMappingTeams)

    def update_teams_integration_mapping_by_id(
        self,
        integration_mapping_id: str,
        *,
        box_item: Optional[FolderReference] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> IntegrationMappingTeams:
        """
                Updates a [Teams integration mapping](https://support.box.com/hc/en-us/articles/360044681474-Using-Box-for-Teams).

                Supports updating the Box folder ID and options.


                You need Admin or Co-Admin role to


                use this endpoint.

                :param integration_mapping_id: An ID of an integration mapping.
        Example: "11235432"
                :type integration_mapping_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'box_item': box_item}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/integration_mappings/teams/',
                        to_string(integration_mapping_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, IntegrationMappingTeams)

    def delete_teams_integration_mapping_by_id(
        self,
        integration_mapping_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes a [Teams integration mapping](https://support.box.com/hc/en-us/articles/360044681474-Using-Box-for-Teams).

                You need Admin or Co-Admin role to


                use this endpoint.

                :param integration_mapping_id: An ID of an integration mapping.
        Example: "11235432"
                :type integration_mapping_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/integration_mappings/teams/',
                        to_string(integration_mapping_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



import pprint
from datetime import datetime
from typing import Any, Dict, Optional

from ..internal.logging import DataSanitizer
from ..internal.errors import GeneratedCodeError


class BoxSDKError(GeneratedCodeError):
    def __init__(
        self,
        message: str,
        timestamp: Optional[datetime] = None,
        error: Optional[Exception] = None,
        **kwargs,
    ):
        super().__init__(message, **kwargs)
        self.name = 'BoxSDKError'
        self.message = message
        self.timestamp = timestamp if timestamp is not None else datetime.now()
        self.error = error

    def __str__(self):
        return ''.join(
            (
                f'\nTimestamp: {self.timestamp}',
                f'\nUnderlying error: {self.error}',
                f'\nMessage: {self.message}',
            )
        )


class RequestInfo:
    def __init__(
        self,
        method: str,
        url: str,
        query_params: Dict[str, str],
        headers: Dict[str, str],
        body: Optional[str] = None,
    ):
        self.method = method
        self.url = url
        self.query_params = query_params
        self.headers = headers
        self.body = body

    def print(self, data_sanitizer: DataSanitizer):
        return ''.join(
            (
                f'\n\tMethod: {self.method}',
                f'\n\tURL: {self.url}',
                f'\n\tQuery params: \n{pprint.pformat(self.query_params, indent=8)}',
                f'\n\tHeaders: \n{pprint.pformat(data_sanitizer.sanitize_headers(self.headers), indent=8)}',
                ''.join(
                    [
                        '\n\tBody: ',
                        '\n' if self.body else '',
                        pprint.pformat(self.body, indent=8),
                    ]
                ),
            )
        )


class ResponseInfo:
    def __init__(
        self,
        status_code: int,
        headers: Dict[str, str],
        body: Dict = None,
        raw_body: Optional[str] = None,
        code: Optional[str] = None,
        context_info: Optional[Dict[str, Any]] = None,
        request_id: Optional[str] = None,
        help_url: Optional[str] = None,
    ):
        self.status_code = status_code
        self.headers = headers
        self.body = body
        self.raw_body = raw_body
        self.code = code
        self.context_info = context_info
        self.request_id = request_id
        self.help_url = help_url

    def print(self, data_sanitizer: DataSanitizer):
        return ''.join(
            (
                f'\n\tStatus code: {self.status_code}',
                f'\n\tHeaders: \n{pprint.pformat(data_sanitizer.sanitize_headers(self.headers), indent=8)}',
                f'\n\tCode: {self.code}',
                f'\n\tContext Info: \n{pprint.pformat(self.context_info, indent=8)}',
                f'\n\tRequest Id: {self.request_id}',
                f'\n\tHelp Url: {self.help_url}',
                ''.join(
                    [
                        '\n\tBody: ',
                        '\n' if self.body else '',
                        pprint.pformat(
                            data_sanitizer.sanitize_body(self.body), indent=8
                        ),
                    ]
                ),
            )
        )


class BoxAPIError(BoxSDKError):
    def __init__(
        self,
        request_info: RequestInfo,
        response_info: ResponseInfo,
        message: str,
        timestamp: Optional[datetime] = None,
        error: Optional[str] = None,
        *,
        data_sanitizer: DataSanitizer = None,
        **kwargs,
    ):
        super().__init__(message=message, timestamp=timestamp, error=error, **kwargs)
        if data_sanitizer is None:
            data_sanitizer = DataSanitizer()
        self.name = 'BoxAPIError'
        self.request_info = request_info
        self.response_info = response_info
        self.data_sanitizer = data_sanitizer

    def __str__(self):
        return ''.join(
            [
                f'\t{super(BoxAPIError, self).__str__()}',
                f'\nRequest: {self.request_info.print(self.data_sanitizer)}',
                f'\nResponse: {self.response_info.print(self.data_sanitizer)}',
            ]
        )



from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from box_sdk_gen.schemas.folder_mini import FolderMini

from box_sdk_gen.schemas.user_base import UserBase

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class FolderLockLockedOperationsField(BaseObject):
    def __init__(self, move: bool, delete: bool, **kwargs):
        """
        :param move: Whether moving the folder is restricted.
        :type move: bool
        :param delete: Whether deleting the folder is restricted.
        :type delete: bool
        """
        super().__init__(**kwargs)
        self.move = move
        self.delete = delete


class FolderLock(BaseObject):
    def __init__(
        self,
        *,
        folder: Optional[FolderMini] = None,
        id: Optional[str] = None,
        type: Optional[str] = None,
        created_by: Optional[UserBase] = None,
        created_at: Optional[DateTime] = None,
        locked_operations: Optional[FolderLockLockedOperationsField] = None,
        lock_type: Optional[str] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for this folder lock., defaults to None
                :type id: Optional[str], optional
                :param type: The object type, always `folder_lock`., defaults to None
                :type type: Optional[str], optional
                :param created_at: When the folder lock object was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param locked_operations: The operations that have been locked. Currently the `move`
        and `delete` operations cannot be locked separately, and both need to be
        set to `true`., defaults to None
                :type locked_operations: Optional[FolderLockLockedOperationsField], optional
                :param lock_type: The lock type, always `freeze`., defaults to None
                :type lock_type: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.folder = folder
        self.id = id
        self.type = type
        self.created_by = created_by
        self.created_at = created_at
        self.locked_operations = locked_operations
        self.lock_type = lock_type



from enum import Enum

from typing import List

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.ai_agent_reference import AiAgentReference

from box_sdk_gen.schemas.ai_agent_ask import AiAgentAsk

from box_sdk_gen.schemas.ai_item_ask import AiItemAsk

from box_sdk_gen.schemas.ai_dialogue_history import AiDialogueHistory

from box_sdk_gen.schemas.ai_ask_agent import AiAskAgent

from box_sdk_gen.box.errors import BoxSDKError


class AiAskModeField(str, Enum):
    MULTIPLE_ITEM_QA = 'multiple_item_qa'
    SINGLE_ITEM_QA = 'single_item_qa'


class AiAsk(BaseObject):
    def __init__(
        self,
        mode: AiAskModeField,
        prompt: str,
        items: List[AiItemAsk],
        *,
        dialogue_history: Optional[List[AiDialogueHistory]] = None,
        include_citations: Optional[bool] = None,
        ai_agent: Optional[AiAskAgent] = None,
        **kwargs
    ):
        """
                :param mode: Box AI handles text documents with text representations up to 1MB in size, or a maximum of 25 files,
        whichever comes first. If the text file size exceeds 1MB, the first 1MB of text representation will be processed.
        Box AI handles image documents with a resolution of 1024 x 1024 pixels, with a maximum of 5 images or 5 pages
        for multi-page images. If the number of image or image pages exceeds 5, the first 5 images or pages will
        be processed. If you set mode parameter to `single_item_qa`, the items array can have one element only.
        Currently Box AI does not support multi-modal requests. If both images and text are sent Box AI will only
        process the text.
                :type mode: AiAskModeField
                :param prompt: The prompt provided by the client to be answered by the LLM.
        The prompt's length is limited to 10000 characters.
                :type prompt: str
                :param items: The items to be processed by the LLM, often files.
                :type items: List[AiItemAsk]
                :param dialogue_history: The history of prompts and answers previously passed to the LLM. This provides additional context to the LLM in generating the response., defaults to None
                :type dialogue_history: Optional[List[AiDialogueHistory]], optional
                :param include_citations: A flag to indicate whether citations should be returned., defaults to None
                :type include_citations: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.mode = mode
        self.prompt = prompt
        self.items = items
        self.dialogue_history = dialogue_history
        self.include_citations = include_citations
        self.ai_agent = ai_agent



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.group_base import GroupBaseTypeField

from box_sdk_gen.schemas.group_base import GroupBase

from box_sdk_gen.schemas.group_mini import GroupMiniGroupTypeField

from box_sdk_gen.schemas.group_mini import GroupMini

from box_sdk_gen.internal.utils import DateTime

from box_sdk_gen.schemas.group import Group

from box_sdk_gen.box.errors import BoxSDKError


class GroupFullInvitabilityLevelField(str, Enum):
    ADMINS_ONLY = 'admins_only'
    ADMINS_AND_MEMBERS = 'admins_and_members'
    ALL_MANAGED_USERS = 'all_managed_users'


class GroupFullMemberViewabilityLevelField(str, Enum):
    ADMINS_ONLY = 'admins_only'
    ADMINS_AND_MEMBERS = 'admins_and_members'
    ALL_MANAGED_USERS = 'all_managed_users'


class GroupFullPermissionsField(BaseObject):
    def __init__(self, *, can_invite_as_collaborator: Optional[bool] = None, **kwargs):
        """
        :param can_invite_as_collaborator: Specifies if the user can invite the group to collaborate on any items., defaults to None
        :type can_invite_as_collaborator: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.can_invite_as_collaborator = can_invite_as_collaborator


class GroupFull(Group):
    def __init__(
        self,
        id: str,
        *,
        provenance: Optional[str] = None,
        external_sync_identifier: Optional[str] = None,
        description: Optional[str] = None,
        invitability_level: Optional[GroupFullInvitabilityLevelField] = None,
        member_viewability_level: Optional[GroupFullMemberViewabilityLevelField] = None,
        permissions: Optional[GroupFullPermissionsField] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        name: Optional[str] = None,
        group_type: Optional[GroupMiniGroupTypeField] = None,
        type: GroupBaseTypeField = GroupBaseTypeField.GROUP,
        **kwargs
    ):
        """
                :param id: The unique identifier for this object.
                :type id: str
                :param provenance: Keeps track of which external source this group is
        coming from (e.g. "Active Directory", "Google Groups",
        "Facebook Groups").  Setting this will
        also prevent Box users from editing the group name
        and its members directly via the Box web application.
        This is desirable for one-way syncing of groups., defaults to None
                :type provenance: Optional[str], optional
                :param external_sync_identifier: An arbitrary identifier that can be used by
        external group sync tools to link this Box Group to
        an external group. Example values of this field
        could be an Active Directory Object ID or a Google
        Group ID.  We recommend you use of this field in
        order to avoid issues when group names are updated in
        either Box or external systems., defaults to None
                :type external_sync_identifier: Optional[str], optional
                :param description: Human readable description of the group., defaults to None
                :type description: Optional[str], optional
                :param invitability_level: Specifies who can invite the group to collaborate
        on items.

        When set to `admins_only` the enterprise admin, co-admins,
        and the group's admin can invite the group.

        When set to `admins_and_members` all the admins listed
        above and group members can invite the group.

        When set to `all_managed_users` all managed users in the
        enterprise can invite the group., defaults to None
                :type invitability_level: Optional[GroupFullInvitabilityLevelField], optional
                :param member_viewability_level: Specifies who can view the members of the group
        (Get Memberships for Group).

        * `admins_only` - the enterprise admin, co-admins, group's
          group admin.
        * `admins_and_members` - all admins and group members.
        * `all_managed_users` - all managed users in the
          enterprise., defaults to None
                :type member_viewability_level: Optional[GroupFullMemberViewabilityLevelField], optional
                :param created_at: When the group object was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param modified_at: When the group object was last modified., defaults to None
                :type modified_at: Optional[DateTime], optional
                :param name: The name of the group., defaults to None
                :type name: Optional[str], optional
                :param group_type: The type of the group., defaults to None
                :type group_type: Optional[GroupMiniGroupTypeField], optional
                :param type: The value will always be `group`., defaults to GroupBaseTypeField.GROUP
                :type type: GroupBaseTypeField, optional
        """
        super().__init__(
            id=id,
            created_at=created_at,
            modified_at=modified_at,
            name=name,
            group_type=group_type,
            type=type,
            **kwargs
        )
        self.provenance = provenance
        self.external_sync_identifier = external_sync_identifier
        self.description = description
        self.invitability_level = invitability_level
        self.member_viewability_level = member_viewability_level
        self.permissions = permissions



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class IntegrationMappingPartnerItemSlackTypeField(str, Enum):
    CHANNEL = 'channel'


class IntegrationMappingPartnerItemSlack(BaseObject):
    _discriminator = 'type', {'channel'}

    def __init__(
        self,
        id: str,
        *,
        type: IntegrationMappingPartnerItemSlackTypeField = IntegrationMappingPartnerItemSlackTypeField.CHANNEL,
        slack_workspace_id: Optional[str] = None,
        slack_org_id: Optional[str] = None,
        **kwargs
    ):
        """
        :param id: ID of the mapped item (of type referenced in `type`).
        :type id: str
        :param type: Type of the mapped item referenced in `id`., defaults to IntegrationMappingPartnerItemSlackTypeField.CHANNEL
        :type type: IntegrationMappingPartnerItemSlackTypeField, optional
        :param slack_workspace_id: ID of the Slack workspace with which the item is associated. Use this parameter if Box for Slack is installed at a workspace level. Do not use `slack_org_id` at the same time., defaults to None
        :type slack_workspace_id: Optional[str], optional
        :param slack_org_id: ID of the Slack org with which the item is associated. Use this parameter if Box for Slack is installed at the org level. Do not use `slack_workspace_id` at the same time., defaults to None
        :type slack_org_id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.slack_workspace_id = slack_workspace_id
        self.slack_org_id = slack_org_id



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class EnterpriseConfigurationItemV2025R0(BaseObject):
    def __init__(self, *, is_used: Optional[bool] = None, **kwargs):
        """
        :param is_used: Indicates whether a configuration is used for a given enterprise., defaults to None
        :type is_used: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.is_used = is_used



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from typing import Optional

from box_sdk_gen.box.errors import BoxSDKError


class ZipDownloadRequestItemsTypeField(str, Enum):
    FILE = 'file'
    FOLDER = 'folder'


class ZipDownloadRequestItemsField(BaseObject):
    _discriminator = 'type', {'file', 'folder'}

    def __init__(self, type: ZipDownloadRequestItemsTypeField, id: str, **kwargs):
        """
                :param type: The type of the item to add to the archive.
                :type type: ZipDownloadRequestItemsTypeField
                :param id: The identifier of the item to add to the archive. When this item is
        a folder then this can not be the root folder with ID `0`.
                :type id: str
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id


class ZipDownloadRequest(BaseObject):
    def __init__(
        self,
        items: List[ZipDownloadRequestItemsField],
        *,
        download_file_name: Optional[str] = None,
        **kwargs
    ):
        """
                :param items: A list of items to add to the `zip` archive. These can
        be folders or files.
                :type items: List[ZipDownloadRequestItemsField]
                :param download_file_name: The optional name of the `zip` archive. This name will be appended by the
        `.zip` file extension, for example `January Financials.zip`., defaults to None
                :type download_file_name: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.items = items
        self.download_file_name = download_file_name



from enum import Enum

from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.folder_mini import FolderMini

from box_sdk_gen.schemas.file_mini import FileMini

from box_sdk_gen.schemas.template_signer import TemplateSigner

from box_sdk_gen.box.errors import BoxSDKError


class SignTemplateTypeField(str, Enum):
    SIGN_TEMPLATE = 'sign-template'


class SignTemplateAdditionalInfoNonEditableField(str, Enum):
    EMAIL_SUBJECT = 'email_subject'
    EMAIL_MESSAGE = 'email_message'
    NAME = 'name'
    DAYS_VALID = 'days_valid'
    SIGNERS = 'signers'
    SOURCE_FILES = 'source_files'


class SignTemplateAdditionalInfoRequiredSignersField(str, Enum):
    EMAIL = 'email'


class SignTemplateAdditionalInfoRequiredField(BaseObject):
    def __init__(
        self,
        *,
        signers: Optional[
            List[List[SignTemplateAdditionalInfoRequiredSignersField]]
        ] = None,
        **kwargs
    ):
        """
        :param signers: Required signer fields., defaults to None
        :type signers: Optional[List[List[SignTemplateAdditionalInfoRequiredSignersField]]], optional
        """
        super().__init__(**kwargs)
        self.signers = signers


class SignTemplateAdditionalInfoField(BaseObject):
    def __init__(
        self,
        *,
        non_editable: Optional[List[SignTemplateAdditionalInfoNonEditableField]] = None,
        required: Optional[SignTemplateAdditionalInfoRequiredField] = None,
        **kwargs
    ):
        """
        :param non_editable: Non editable fields., defaults to None
        :type non_editable: Optional[List[SignTemplateAdditionalInfoNonEditableField]], optional
        :param required: Required fields., defaults to None
        :type required: Optional[SignTemplateAdditionalInfoRequiredField], optional
        """
        super().__init__(**kwargs)
        self.non_editable = non_editable
        self.required = required


class SignTemplateReadySignLinkField(BaseObject):
    def __init__(
        self,
        *,
        url: Optional[str] = None,
        name: Optional[str] = None,
        instructions: Optional[str] = None,
        folder_id: Optional[str] = None,
        is_notification_disabled: Optional[bool] = None,
        is_active: Optional[bool] = None,
        **kwargs
    ):
        """
                :param url: The URL that can be sent to signers., defaults to None
                :type url: Optional[str], optional
                :param name: Request name., defaults to None
                :type name: Optional[str], optional
                :param instructions: Extra instructions for all signers., defaults to None
                :type instructions: Optional[str], optional
                :param folder_id: The destination folder to place final,
        signed document and signing
        log. Only `ID` and `type` fields are required.
        The root folder,
        folder ID `0`, cannot be used., defaults to None
                :type folder_id: Optional[str], optional
                :param is_notification_disabled: Whether to disable notifications when
        a signer has signed., defaults to None
                :type is_notification_disabled: Optional[bool], optional
                :param is_active: Whether the ready sign link is enabled or not., defaults to None
                :type is_active: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.url = url
        self.name = name
        self.instructions = instructions
        self.folder_id = folder_id
        self.is_notification_disabled = is_notification_disabled
        self.is_active = is_active


class SignTemplateCustomBrandingField(BaseObject):
    def __init__(
        self,
        *,
        company_name: Optional[str] = None,
        logo_uri: Optional[str] = None,
        branding_color: Optional[str] = None,
        email_footer_text: Optional[str] = None,
        **kwargs
    ):
        """
        :param company_name: Name of the company., defaults to None
        :type company_name: Optional[str], optional
        :param logo_uri: Custom branding logo URI in the form of a base64 image., defaults to None
        :type logo_uri: Optional[str], optional
        :param branding_color: Custom branding color in hex., defaults to None
        :type branding_color: Optional[str], optional
        :param email_footer_text: Content of the email footer., defaults to None
        :type email_footer_text: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.company_name = company_name
        self.logo_uri = logo_uri
        self.branding_color = branding_color
        self.email_footer_text = email_footer_text


class SignTemplate(BaseObject):
    _discriminator = 'type', {'sign-template'}

    def __init__(
        self,
        *,
        type: Optional[SignTemplateTypeField] = None,
        id: Optional[str] = None,
        name: Optional[str] = None,
        email_subject: Optional[str] = None,
        email_message: Optional[str] = None,
        days_valid: Optional[int] = None,
        parent_folder: Optional[FolderMini] = None,
        source_files: Optional[List[FileMini]] = None,
        are_fields_locked: Optional[bool] = None,
        are_options_locked: Optional[bool] = None,
        are_recipients_locked: Optional[bool] = None,
        are_email_settings_locked: Optional[bool] = None,
        are_files_locked: Optional[bool] = None,
        signers: Optional[List[TemplateSigner]] = None,
        additional_info: Optional[SignTemplateAdditionalInfoField] = None,
        ready_sign_link: Optional[SignTemplateReadySignLinkField] = None,
        custom_branding: Optional[SignTemplateCustomBrandingField] = None,
        **kwargs
    ):
        """
                :param type: The value will always be `sign-template`., defaults to None
                :type type: Optional[SignTemplateTypeField], optional
                :param id: Template identifier., defaults to None
                :type id: Optional[str], optional
                :param name: The name of the template., defaults to None
                :type name: Optional[str], optional
                :param email_subject: Subject of signature request email. This is cleaned by sign
        request. If this field is not passed, a default subject will be used., defaults to None
                :type email_subject: Optional[str], optional
                :param email_message: Message to include in signature request email. The field
        is cleaned through sanitization of specific characters. However,
        some html tags are allowed. Links included in the
        message are also converted to hyperlinks in the email. The
        message may contain the following html tags including `a`, `abbr`,
        `acronym`, `b`, `blockquote`, `code`, `em`, `i`, `ul`, `li`, `ol`, and
        `strong`. Be aware that when the text
        to html ratio is too high, the email
        may end up in spam filters. Custom styles on
        these tags are not allowed.
        If this field is not passed, a default message will be used., defaults to None
                :type email_message: Optional[str], optional
                :param days_valid: Set the number of days after which the
        created signature request will automatically
        expire if not completed. By default, we do
        not apply any expiration date on signature
        requests, and the signature request does not expire., defaults to None
                :type days_valid: Optional[int], optional
                :param source_files: List of files to create a signing document from.
        Only the ID and type fields are required
        for each file., defaults to None
                :type source_files: Optional[List[FileMini]], optional
                :param are_fields_locked: Indicates if the template input
        fields are editable or not., defaults to None
                :type are_fields_locked: Optional[bool], optional
                :param are_options_locked: Indicates if the template document options
        are editable or not,
        for example renaming the document., defaults to None
                :type are_options_locked: Optional[bool], optional
                :param are_recipients_locked: Indicates if the template signers are editable or not., defaults to None
                :type are_recipients_locked: Optional[bool], optional
                :param are_email_settings_locked: Indicates if the template email settings are editable or not., defaults to None
                :type are_email_settings_locked: Optional[bool], optional
                :param are_files_locked: Indicates if the template files are editable or not.
        This includes deleting or renaming template files., defaults to None
                :type are_files_locked: Optional[bool], optional
                :param signers: Array of signers for the template.

        **Note**: It may happen that some signers specified in the template belong to conflicting [segments](https://developer.box.com/reference/resources/shield-information-barrier-segment-member) (user groups).
        This means that due to the security policies, users are assigned to segments to prevent exchanges or communication that could lead to ethical conflicts.
        In such a case, an attempt to send a sign request based on a template that lists signers in conflicting segments will result in an error.

        Read more about [segments and ethical walls](https://support.box.com/hc/en-us/articles/9920431507603-Understanding-Information-Barriers#h_01GFVJEHQA06N7XEZ4GCZ9GFAQ)., defaults to None
                :type signers: Optional[List[TemplateSigner]], optional
                :param additional_info: Additional information on which fields are
        required and which fields are not editable., defaults to None
                :type additional_info: Optional[SignTemplateAdditionalInfoField], optional
                :param ready_sign_link: Box's ready-sign link feature enables you to create a
        link to a signature request that
        you've created from a template. Use this link
        when you want to post a signature request
        on a public form — such as an email, social media post,
        or web page — without knowing who the signers will be.
        Note: The ready-sign link feature is
        limited to Enterprise Plus customers and not
        available to Box Verified Enterprises., defaults to None
                :type ready_sign_link: Optional[SignTemplateReadySignLinkField], optional
                :param custom_branding: Custom branding applied to notifications
        and signature requests., defaults to None
                :type custom_branding: Optional[SignTemplateCustomBrandingField], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id
        self.name = name
        self.email_subject = email_subject
        self.email_message = email_message
        self.days_valid = days_valid
        self.parent_folder = parent_folder
        self.source_files = source_files
        self.are_fields_locked = are_fields_locked
        self.are_options_locked = are_options_locked
        self.are_recipients_locked = are_recipients_locked
        self.are_email_settings_locked = are_email_settings_locked
        self.are_files_locked = are_files_locked
        self.signers = signers
        self.additional_info = additional_info
        self.ready_sign_link = ready_sign_link
        self.custom_branding = custom_branding



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.internal.null_value import NullValue

from typing import Union

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.web_link import WebLink

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData

from box_sdk_gen.internal.utils import DateTime


class AddShareLinkToWebLinkSharedLinkAccessField(str, Enum):
    OPEN = 'open'
    COMPANY = 'company'
    COLLABORATORS = 'collaborators'


class AddShareLinkToWebLinkSharedLinkPermissionsField(BaseObject):
    def __init__(
        self,
        *,
        can_download: Optional[bool] = None,
        can_preview: Optional[bool] = None,
        can_edit: Optional[bool] = None,
        **kwargs
    ):
        """
                :param can_download: If the shared link allows for downloading of files.
        This can only be set when `access` is set to
        `open` or `company`., defaults to None
                :type can_download: Optional[bool], optional
                :param can_preview: If the shared link allows for previewing of files.
        This value is always `true`. For shared links on folders
        this also applies to any items in the folder., defaults to None
                :type can_preview: Optional[bool], optional
                :param can_edit: This value can only be `true` is `type` is `file`., defaults to None
                :type can_edit: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.can_download = can_download
        self.can_preview = can_preview
        self.can_edit = can_edit


class AddShareLinkToWebLinkSharedLink(BaseObject):
    def __init__(
        self,
        *,
        access: Optional[AddShareLinkToWebLinkSharedLinkAccessField] = None,
        password: Optional[str] = None,
        vanity_name: Optional[str] = None,
        unshared_at: Optional[DateTime] = None,
        permissions: Optional[AddShareLinkToWebLinkSharedLinkPermissionsField] = None,
        **kwargs
    ):
        """
                :param access: The level of access for the shared link. This can be
        restricted to anyone with the link (`open`), only people
        within the company (`company`) and only those who
        have been invited to the file (`collaborators`).

        If not set, this field defaults to the access level specified
        by the enterprise admin. To create a shared link with this
        default setting pass the `shared_link` object with
        no `access` field, for example `{ "shared_link": {} }`.

        The `company` access level is only available to paid
        accounts., defaults to None
                :type access: Optional[AddShareLinkToWebLinkSharedLinkAccessField], optional
                :param password: The password required to access the shared link. Set the
        password to `null` to remove it.
        Passwords must now be at least eight characters
        long and include a number, upper case letter, or
        a non-numeric or non-alphabetic character.
        A password can only be set when `access` is set to `open`., defaults to None
                :type password: Optional[str], optional
                :param vanity_name: Defines a custom vanity name to use in the shared link URL,
        for example `https://app.box.com/v/my-shared-link`.

        Custom URLs should not be used when sharing sensitive content
        as vanity URLs are a lot easier to guess than regular shared
        links., defaults to None
                :type vanity_name: Optional[str], optional
                :param unshared_at: The timestamp at which this shared link will
        expire. This field can only be set by
        users with paid accounts. The value must be greater than the
        current date and time., defaults to None
                :type unshared_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.access = access
        self.password = password
        self.vanity_name = vanity_name
        self.unshared_at = unshared_at
        self.permissions = permissions


class UpdateSharedLinkOnWebLinkSharedLinkAccessField(str, Enum):
    OPEN = 'open'
    COMPANY = 'company'
    COLLABORATORS = 'collaborators'


class UpdateSharedLinkOnWebLinkSharedLinkPermissionsField(BaseObject):
    def __init__(
        self,
        *,
        can_download: Optional[bool] = None,
        can_preview: Optional[bool] = None,
        can_edit: Optional[bool] = None,
        **kwargs
    ):
        """
                :param can_download: If the shared link allows for downloading of files.
        This can only be set when `access` is set to
        `open` or `company`., defaults to None
                :type can_download: Optional[bool], optional
                :param can_preview: If the shared link allows for previewing of files.
        This value is always `true`. For shared links on folders
        this also applies to any items in the folder., defaults to None
                :type can_preview: Optional[bool], optional
                :param can_edit: This value can only be `true` is `type` is `file`., defaults to None
                :type can_edit: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.can_download = can_download
        self.can_preview = can_preview
        self.can_edit = can_edit


class UpdateSharedLinkOnWebLinkSharedLink(BaseObject):
    def __init__(
        self,
        *,
        access: Optional[UpdateSharedLinkOnWebLinkSharedLinkAccessField] = None,
        password: Optional[str] = None,
        vanity_name: Optional[str] = None,
        unshared_at: Optional[DateTime] = None,
        permissions: Optional[
            UpdateSharedLinkOnWebLinkSharedLinkPermissionsField
        ] = None,
        **kwargs
    ):
        """
                :param access: The level of access for the shared link. This can be
        restricted to anyone with the link (`open`), only people
        within the company (`company`) and only those who
        have been invited to the folder (`collaborators`).

        If not set, this field defaults to the access level specified
        by the enterprise admin. To create a shared link with this
        default setting pass the `shared_link` object with
        no `access` field, for example `{ "shared_link": {} }`.

        The `company` access level is only available to paid
        accounts., defaults to None
                :type access: Optional[UpdateSharedLinkOnWebLinkSharedLinkAccessField], optional
                :param password: The password required to access the shared link. Set the
        password to `null` to remove it.
        Passwords must now be at least eight characters
        long and include a number, upper case letter, or
        a non-numeric or non-alphabetic character.
        A password can only be set when `access` is set to `open`., defaults to None
                :type password: Optional[str], optional
                :param vanity_name: Defines a custom vanity name to use in the shared link URL,
        for example `https://app.box.com/v/my-shared-link`.

        Custom URLs should not be used when sharing sensitive content
        as vanity URLs are a lot easier to guess than regular shared
        links., defaults to None
                :type vanity_name: Optional[str], optional
                :param unshared_at: The timestamp at which this shared link will
        expire. This field can only be set by
        users with paid accounts. The value must be greater than the
        current date and time., defaults to None
                :type unshared_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.access = access
        self.password = password
        self.vanity_name = vanity_name
        self.unshared_at = unshared_at
        self.permissions = permissions


class RemoveSharedLinkFromWebLinkSharedLink(BaseObject):
    def __init__(self, **kwargs):
        super().__init__(**kwargs)


class SharedLinksWebLinksManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def find_web_link_for_shared_link(
        self,
        boxapi: str,
        *,
        fields: Optional[List[str]] = None,
        if_none_match: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> WebLink:
        """
                Returns the web link represented by a shared link.

                A shared web link can be represented by a shared link,


                which can originate within the current enterprise or within another.


                This endpoint allows an application to retrieve information about a


                shared web link when only given a shared link.

                :param boxapi: A header containing the shared link and optional password for the
        shared link.

        The format for this header is as follows:

        `shared_link=[link]&shared_link_password=[password]`.
                :type boxapi: str
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param if_none_match: Ensures an item is only returned if it has changed.

        Pass in the item's last observed `etag` value
        into this header and the endpoint will fail
        with a `304 Not Modified` if the item has not
        changed since., defaults to None
                :type if_none_match: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params(
            {
                'if-none-match': to_string(if_none_match),
                'boxapi': to_string(boxapi),
                **extra_headers,
            }
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/shared_items#web_links',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, WebLink)

    def get_shared_link_for_web_link(
        self,
        web_link_id: str,
        fields: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> WebLink:
        """
                Gets the information for a shared link on a web link.
                :param web_link_id: The ID of the web link.
        Example: "12345"
                :type web_link_id: str
                :param fields: Explicitly request the `shared_link` fields
        to be returned for this item.
                :type fields: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/web_links/',
                        to_string(web_link_id),
                        '#get_shared_link',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, WebLink)

    def add_share_link_to_web_link(
        self,
        web_link_id: str,
        fields: str,
        *,
        shared_link: Optional[AddShareLinkToWebLinkSharedLink] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> WebLink:
        """
                Adds a shared link to a web link.
                :param web_link_id: The ID of the web link.
        Example: "12345"
                :type web_link_id: str
                :param fields: Explicitly request the `shared_link` fields
        to be returned for this item.
                :type fields: str
                :param shared_link: The settings for the shared link to create on the web link.

        Use an empty object (`{}`) to use the default settings for shared
        links., defaults to None
                :type shared_link: Optional[AddShareLinkToWebLinkSharedLink], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'shared_link': shared_link}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/web_links/',
                        to_string(web_link_id),
                        '#add_shared_link',
                    ]
                ),
                method='PUT',
                params=query_params_map,
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, WebLink)

    def update_shared_link_on_web_link(
        self,
        web_link_id: str,
        fields: str,
        *,
        shared_link: Optional[UpdateSharedLinkOnWebLinkSharedLink] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> WebLink:
        """
                Updates a shared link on a web link.
                :param web_link_id: The ID of the web link.
        Example: "12345"
                :type web_link_id: str
                :param fields: Explicitly request the `shared_link` fields
        to be returned for this item.
                :type fields: str
                :param shared_link: The settings for the shared link to update., defaults to None
                :type shared_link: Optional[UpdateSharedLinkOnWebLinkSharedLink], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'shared_link': shared_link}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/web_links/',
                        to_string(web_link_id),
                        '#update_shared_link',
                    ]
                ),
                method='PUT',
                params=query_params_map,
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, WebLink)

    def remove_shared_link_from_web_link(
        self,
        web_link_id: str,
        fields: str,
        *,
        shared_link: Union[
            Optional[RemoveSharedLinkFromWebLinkSharedLink], NullValue
        ] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> WebLink:
        """
                Removes a shared link from a web link.
                :param web_link_id: The ID of the web link.
        Example: "12345"
                :type web_link_id: str
                :param fields: Explicitly request the `shared_link` fields
        to be returned for this item.
                :type fields: str
                :param shared_link: By setting this value to `null`, the shared link
        is removed from the web link., defaults to None
                :type shared_link: Union[Optional[RemoveSharedLinkFromWebLinkSharedLink], NullValue], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'shared_link': shared_link}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/web_links/',
                        to_string(web_link_id),
                        '#remove_shared_link',
                    ]
                ),
                method='PUT',
                params=query_params_map,
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, WebLink)



from typing import Optional

from typing import Dict

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class MetadataTaxonomyAncestor(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'display_name': 'displayName',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'displayName': 'display_name',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        display_name: Optional[str] = None,
        level: Optional[int] = None,
        **kwargs
    ):
        """
        :param id: A unique identifier of the metadata taxonomy node., defaults to None
        :type id: Optional[str], optional
        :param display_name: The display name of the metadata taxonomy node., defaults to None
        :type display_name: Optional[str], optional
        :param level: An index of the level to which the node belongs., defaults to None
        :type level: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.display_name = display_name
        self.level = level



from enum import Enum

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.device_pinner import DevicePinner

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.device_pinners import DevicePinners

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class GetEnterpriseDevicePinnersDirection(str, Enum):
    ASC = 'ASC'
    DESC = 'DESC'


class DevicePinnersManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_device_pinner_by_id(
        self,
        device_pinner_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> DevicePinner:
        """
                Retrieves information about an individual device pin.
                :param device_pinner_id: The ID of the device pin.
        Example: "2324234"
                :type device_pinner_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/device_pinners/',
                        to_string(device_pinner_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, DevicePinner)

    def delete_device_pinner_by_id(
        self,
        device_pinner_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes an individual device pin.
                :param device_pinner_id: The ID of the device pin.
        Example: "2324234"
                :type device_pinner_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/device_pinners/',
                        to_string(device_pinner_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def get_enterprise_device_pinners(
        self,
        enterprise_id: str,
        *,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        direction: Optional[GetEnterpriseDevicePinnersDirection] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> DevicePinners:
        """
                Retrieves all the device pins within an enterprise.

                The user must have admin privileges, and the application


                needs the "manage enterprise" scope to make this call.

                :param enterprise_id: The ID of the enterprise.
        Example: "3442311"
                :type enterprise_id: str
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param direction: The direction to sort results in. This can be either in alphabetical ascending
        (`ASC`) or descending (`DESC`) order., defaults to None
                :type direction: Optional[GetEnterpriseDevicePinnersDirection], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'marker': to_string(marker),
                'limit': to_string(limit),
                'direction': to_string(direction),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/enterprises/',
                        to_string(enterprise_id),
                        '/device_pinners',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, DevicePinners)



from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.storage_policies import StoragePolicies

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.storage_policy import StoragePolicy

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class StoragePoliciesManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_storage_policies(
        self,
        *,
        fields: Optional[List[str]] = None,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> StoragePolicies:
        """
                Fetches all the storage policies in the enterprise.
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'fields': to_string(fields),
                'marker': to_string(marker),
                'limit': to_string(limit),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/storage_policies']
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, StoragePolicies)

    def get_storage_policy_by_id(
        self,
        storage_policy_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> StoragePolicy:
        """
                Fetches a specific storage policy.
                :param storage_policy_id: The ID of the storage policy.
        Example: "34342"
                :type storage_policy_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/storage_policies/',
                        to_string(storage_policy_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, StoragePolicy)



from typing import Optional

from box_sdk_gen.schemas.ai_llm_endpoint_params_open_ai import AiLlmEndpointParamsOpenAi

from box_sdk_gen.schemas.ai_llm_endpoint_params_google import AiLlmEndpointParamsGoogle

from box_sdk_gen.schemas.ai_llm_endpoint_params_aws import AiLlmEndpointParamsAws

from box_sdk_gen.schemas.ai_llm_endpoint_params_ibm import AiLlmEndpointParamsIbm

from box_sdk_gen.schemas.ai_llm_endpoint_params import AiLlmEndpointParams

from box_sdk_gen.schemas.ai_agent_spreadsheet_tool import AiAgentSpreadsheetTool

from box_sdk_gen.box.errors import BoxSDKError


class AiStudioAgentSpreadsheetTool(AiAgentSpreadsheetTool):
    def __init__(
        self,
        *,
        model: Optional[str] = None,
        num_tokens_for_completion: Optional[int] = None,
        llm_endpoint_params: Optional[AiLlmEndpointParams] = None,
        **kwargs
    ):
        """
        :param model: The model used for the AI agent for spreadsheets. For specific model values, see the [available models list](https://developer.box.com/guides/box-ai/supported-models)., defaults to None
        :type model: Optional[str], optional
        :param num_tokens_for_completion: The number of tokens for completion., defaults to None
        :type num_tokens_for_completion: Optional[int], optional
        """
        super().__init__(
            model=model,
            num_tokens_for_completion=num_tokens_for_completion,
            llm_endpoint_params=llm_endpoint_params,
            **kwargs
        )



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class IntegrationMappingBoxItemSlackTypeField(str, Enum):
    FOLDER = 'folder'


class IntegrationMappingBoxItemSlack(BaseObject):
    _discriminator = 'type', {'folder'}

    def __init__(
        self,
        id: str,
        *,
        type: IntegrationMappingBoxItemSlackTypeField = IntegrationMappingBoxItemSlackTypeField.FOLDER,
        **kwargs
    ):
        """
        :param id: ID of the mapped item (of type referenced in `type`).
        :type id: str
        :param type: Type of the mapped item referenced in `id`., defaults to IntegrationMappingBoxItemSlackTypeField.FOLDER
        :type type: IntegrationMappingBoxItemSlackTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class TrackingCodeTypeField(str, Enum):
    TRACKING_CODE = 'tracking_code'


class TrackingCode(BaseObject):
    _discriminator = 'type', {'tracking_code'}

    def __init__(
        self,
        *,
        type: Optional[TrackingCodeTypeField] = None,
        name: Optional[str] = None,
        value: Optional[str] = None,
        **kwargs
    ):
        """
                :param type: The value will always be `tracking_code`., defaults to None
                :type type: Optional[TrackingCodeTypeField], optional
                :param name: The name of the tracking code, which must be preconfigured in
        the Admin Console., defaults to None
                :type name: Optional[str], optional
                :param value: The value of the tracking code., defaults to None
                :type value: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.name = name
        self.value = value



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class WatermarkWatermarkField(BaseObject):
    def __init__(
        self,
        *,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        **kwargs
    ):
        """
        :param created_at: When this watermark was created., defaults to None
        :type created_at: Optional[DateTime], optional
        :param modified_at: When this task was modified., defaults to None
        :type modified_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.created_at = created_at
        self.modified_at = modified_at


class Watermark(BaseObject):
    def __init__(
        self, *, watermark: Optional[WatermarkWatermarkField] = None, **kwargs
    ):
        super().__init__(**kwargs)
        self.watermark = watermark



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.ai_agent_long_text_tool import AiAgentLongTextTool

from box_sdk_gen.schemas.ai_agent_basic_text_tool import AiAgentBasicTextTool

from box_sdk_gen.box.errors import BoxSDKError


class AiAgentExtractTypeField(str, Enum):
    AI_AGENT_EXTRACT = 'ai_agent_extract'


class AiAgentExtract(BaseObject):
    _discriminator = 'type', {'ai_agent_extract'}

    def __init__(
        self,
        *,
        type: AiAgentExtractTypeField = AiAgentExtractTypeField.AI_AGENT_EXTRACT,
        long_text: Optional[AiAgentLongTextTool] = None,
        basic_text: Optional[AiAgentBasicTextTool] = None,
        basic_image: Optional[AiAgentBasicTextTool] = None,
        **kwargs
    ):
        """
        :param type: The type of AI agent to be used for extraction., defaults to AiAgentExtractTypeField.AI_AGENT_EXTRACT
        :type type: AiAgentExtractTypeField, optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.long_text = long_text
        self.basic_text = basic_text
        self.basic_image = basic_image



from enum import Enum

from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.resource_scope import ResourceScope

from box_sdk_gen.box.errors import BoxSDKError


class AccessTokenTokenTypeField(str, Enum):
    BEARER = 'bearer'


class AccessTokenIssuedTokenTypeField(str, Enum):
    URN_IETF_PARAMS_OAUTH_TOKEN_TYPE_ACCESS_TOKEN = (
        'urn:ietf:params:oauth:token-type:access_token'
    )


class AccessToken(BaseObject):
    def __init__(
        self,
        *,
        access_token: Optional[str] = None,
        expires_in: Optional[int] = None,
        token_type: Optional[AccessTokenTokenTypeField] = None,
        restricted_to: Optional[List[ResourceScope]] = None,
        refresh_token: Optional[str] = None,
        issued_token_type: Optional[AccessTokenIssuedTokenTypeField] = None,
        **kwargs
    ):
        """
                :param access_token: The requested access token., defaults to None
                :type access_token: Optional[str], optional
                :param expires_in: The time in seconds by which this token will expire., defaults to None
                :type expires_in: Optional[int], optional
                :param token_type: The type of access token returned., defaults to None
                :type token_type: Optional[AccessTokenTokenTypeField], optional
                :param restricted_to: The permissions that this access token permits,
        providing a list of resources (files, folders, etc)
        and the scopes permitted for each of those resources., defaults to None
                :type restricted_to: Optional[List[ResourceScope]], optional
                :param refresh_token: The refresh token for this access token, which can be used
        to request a new access token when the current one expires., defaults to None
                :type refresh_token: Optional[str], optional
                :param issued_token_type: The type of downscoped access token returned. This is only
        returned if an access token has been downscoped., defaults to None
                :type issued_token_type: Optional[AccessTokenIssuedTokenTypeField], optional
        """
        super().__init__(**kwargs)
        self.access_token = access_token
        self.expires_in = expires_in
        self.token_type = token_type
        self.restricted_to = restricted_to
        self.refresh_token = refresh_token
        self.issued_token_type = issued_token_type



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.shield_information_barrier_base import (
    ShieldInformationBarrierBase,
)

from box_sdk_gen.box.errors import BoxSDKError


class ShieldInformationBarrierReference(BaseObject):
    def __init__(
        self,
        *,
        shield_information_barrier: Optional[ShieldInformationBarrierBase] = None,
        **kwargs
    ):
        super().__init__(**kwargs)
        self.shield_information_barrier = shield_information_barrier



from typing import Optional


class TimeoutConfig:
    def __init__(
        self,
        *,
        connection_timeout_ms: Optional[int] = None,
        read_timeout_ms: Optional[int] = None
    ):
        self.connection_timeout_ms = connection_timeout_ms
        self.read_timeout_ms = read_timeout_ms



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class UploadPartMini(BaseObject):
    def __init__(
        self,
        *,
        part_id: Optional[str] = None,
        offset: Optional[int] = None,
        size: Optional[int] = None,
        **kwargs
    ):
        """
                :param part_id: The unique ID of the chunk., defaults to None
                :type part_id: Optional[str], optional
                :param offset: The offset of the chunk within the file
        in bytes. The lower bound of the position
        of the chunk within the file., defaults to None
                :type offset: Optional[int], optional
                :param size: The size of the chunk in bytes., defaults to None
                :type size: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.part_id = part_id
        self.offset = offset
        self.size = size



from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.metadata_taxonomy_ancestor import MetadataTaxonomyAncestor

from box_sdk_gen.box.errors import BoxSDKError


class MetadataTaxonomyNode(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'display_name': 'displayName',
        'parent_id': 'parentId',
        'node_path': 'nodePath',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'displayName': 'display_name',
        'parentId': 'parent_id',
        'nodePath': 'node_path',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        id: str,
        display_name: str,
        level: int,
        *,
        parent_id: Optional[str] = None,
        node_path: Optional[List[str]] = None,
        ancestors: Optional[List[MetadataTaxonomyAncestor]] = None,
        **kwargs
    ):
        """
                :param id: A unique identifier of the metadata taxonomy node.
                :type id: str
                :param display_name: The display name of the metadata taxonomy node.
                :type display_name: str
                :param level: An index of the level to which the node belongs.
                :type level: int
                :param parent_id: The identifier of the parent node., defaults to None
                :type parent_id: Optional[str], optional
                :param node_path: An array of identifiers for all ancestor nodes.
        Not returned for root-level nodes., defaults to None
                :type node_path: Optional[List[str]], optional
                :param ancestors: An array of objects for all ancestor nodes.
        Not returned for root-level nodes., defaults to None
                :type ancestors: Optional[List[MetadataTaxonomyAncestor]], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.display_name = display_name
        self.level = level
        self.parent_id = parent_id
        self.node_path = node_path
        self.ancestors = ancestors



from typing import Union

from box_sdk_gen.schemas.search_results import SearchResults

from box_sdk_gen.schemas.search_results_with_shared_links import (
    SearchResultsWithSharedLinks,
)

from box_sdk_gen.box.errors import BoxSDKError

SearchResultsResponse = Union[SearchResults, SearchResultsWithSharedLinks]



from typing import Union

from box_sdk_gen.schemas.user_collaborations import UserCollaborations

from box_sdk_gen.schemas.group_mini import GroupMini

from box_sdk_gen.box.errors import BoxSDKError

CollaborationAccessGrantee = Union[UserCollaborations, GroupMini]



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.internal.utils import Date

from box_sdk_gen.schemas.sign_request_signer_input_email_validation import (
    SignRequestSignerInputEmailValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_custom_validation import (
    SignRequestSignerInputCustomValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_zip_validation import (
    SignRequestSignerInputZipValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_zip_4_validation import (
    SignRequestSignerInputZip4Validation,
)

from box_sdk_gen.schemas.sign_request_signer_input_ssn_validation import (
    SignRequestSignerInputSsnValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_number_with_period_validation import (
    SignRequestSignerInputNumberWithPeriodValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_number_with_comma_validation import (
    SignRequestSignerInputNumberWithCommaValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_date_iso_validation import (
    SignRequestSignerInputDateIsoValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_date_us_validation import (
    SignRequestSignerInputDateUsValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_date_eu_validation import (
    SignRequestSignerInputDateEuValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_date_asia_validation import (
    SignRequestSignerInputDateAsiaValidation,
)

from box_sdk_gen.schemas.sign_request_prefill_tag import SignRequestPrefillTag

from box_sdk_gen.schemas.sign_request_signer_input_validation import (
    SignRequestSignerInputValidation,
)

from box_sdk_gen.box.errors import BoxSDKError


class TemplateSignerInputTypeField(str, Enum):
    SIGNATURE = 'signature'
    DATE = 'date'
    TEXT = 'text'
    CHECKBOX = 'checkbox'
    ATTACHMENT = 'attachment'
    RADIO = 'radio'
    DROPDOWN = 'dropdown'


class TemplateSignerInputContentTypeField(str, Enum):
    SIGNATURE = 'signature'
    INITIAL = 'initial'
    STAMP = 'stamp'
    DATE = 'date'
    CHECKBOX = 'checkbox'
    TEXT = 'text'
    FULL_NAME = 'full_name'
    FIRST_NAME = 'first_name'
    LAST_NAME = 'last_name'
    COMPANY = 'company'
    TITLE = 'title'
    EMAIL = 'email'
    ATTACHMENT = 'attachment'
    RADIO = 'radio'
    DROPDOWN = 'dropdown'


class TemplateSignerInputCoordinatesField(BaseObject):
    def __init__(
        self, *, x: Optional[float] = None, y: Optional[float] = None, **kwargs
    ):
        """
        :param x: Relative x coordinate to the page the input is on, ranging from 0 to 1., defaults to None
        :type x: Optional[float], optional
        :param y: Relative y coordinate to the page the input is on, ranging from 0 to 1., defaults to None
        :type y: Optional[float], optional
        """
        super().__init__(**kwargs)
        self.x = x
        self.y = y


class TemplateSignerInputDimensionsField(BaseObject):
    def __init__(
        self, *, width: Optional[float] = None, height: Optional[float] = None, **kwargs
    ):
        """
        :param width: Relative width to the page the input is on, ranging from 0 to 1., defaults to None
        :type width: Optional[float], optional
        :param height: Relative height to the page the input is on, ranging from 0 to 1., defaults to None
        :type height: Optional[float], optional
        """
        super().__init__(**kwargs)
        self.width = width
        self.height = height


class TemplateSignerInput(SignRequestPrefillTag):
    def __init__(
        self,
        page_index: int,
        *,
        type: Optional[TemplateSignerInputTypeField] = None,
        content_type: Optional[TemplateSignerInputContentTypeField] = None,
        is_required: Optional[bool] = None,
        document_id: Optional[str] = None,
        dropdown_choices: Optional[List[str]] = None,
        group_id: Optional[str] = None,
        coordinates: Optional[TemplateSignerInputCoordinatesField] = None,
        dimensions: Optional[TemplateSignerInputDimensionsField] = None,
        label: Optional[str] = None,
        read_only: Optional[bool] = None,
        validation: Optional[SignRequestSignerInputValidation] = None,
        document_tag_id: Optional[str] = None,
        text_value: Optional[str] = None,
        checkbox_value: Optional[bool] = None,
        date_value: Optional[Date] = None,
        **kwargs
    ):
        """
                :param page_index: Index of page that the input is on.
                :type page_index: int
                :param type: Type of input., defaults to None
                :type type: Optional[TemplateSignerInputTypeField], optional
                :param content_type: Content type of input., defaults to None
                :type content_type: Optional[TemplateSignerInputContentTypeField], optional
                :param is_required: Whether or not the input is required., defaults to None
                :type is_required: Optional[bool], optional
                :param document_id: Document identifier., defaults to None
                :type document_id: Optional[str], optional
                :param dropdown_choices: When the input is of the type `dropdown` this
        values will be filled with all the
        dropdown options., defaults to None
                :type dropdown_choices: Optional[List[str]], optional
                :param group_id: When the input is of type `radio` they can be
        grouped to gather with this identifier., defaults to None
                :type group_id: Optional[str], optional
                :param coordinates: Where the input is located on a page., defaults to None
                :type coordinates: Optional[TemplateSignerInputCoordinatesField], optional
                :param dimensions: The size of the input., defaults to None
                :type dimensions: Optional[TemplateSignerInputDimensionsField], optional
                :param label: The label field is used especially for text, attachment, radio, and checkbox type inputs., defaults to None
                :type label: Optional[str], optional
                :param read_only: Indicates whether this input is read-only (cannot be modified by signers)., defaults to None
                :type read_only: Optional[bool], optional
                :param validation: Specifies the formatting rules that signers must follow for text field inputs.
        If set, this validation is mandatory., defaults to None
                :type validation: Optional[SignRequestSignerInputValidation], optional
                :param document_tag_id: This references the ID of a specific tag contained in a file of the signature request., defaults to None
                :type document_tag_id: Optional[str], optional
                :param text_value: Text prefill value., defaults to None
                :type text_value: Optional[str], optional
                :param checkbox_value: Checkbox prefill value., defaults to None
                :type checkbox_value: Optional[bool], optional
                :param date_value: Date prefill value., defaults to None
                :type date_value: Optional[Date], optional
        """
        super().__init__(
            document_tag_id=document_tag_id,
            text_value=text_value,
            checkbox_value=checkbox_value,
            date_value=date_value,
            **kwargs
        )
        self.page_index = page_index
        self.type = type
        self.content_type = content_type
        self.is_required = is_required
        self.document_id = document_id
        self.dropdown_choices = dropdown_choices
        self.group_id = group_id
        self.coordinates = coordinates
        self.dimensions = dimensions
        self.label = label
        self.read_only = read_only
        self.validation = validation



from typing import Union

from box_sdk_gen.schemas.v2025_r0.file_reference_v2025_r0 import FileReferenceV2025R0

from box_sdk_gen.schemas.v2025_r0.folder_reference_v2025_r0 import (
    FolderReferenceV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.weblink_reference_v2025_r0 import (
    WeblinkReferenceV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError

HubItemReferenceV2025R0 = Union[
    FileReferenceV2025R0, FolderReferenceV2025R0, WeblinkReferenceV2025R0
]



from typing import Optional

from box_sdk_gen.schemas.storage_policy_mini import StoragePolicyMiniTypeField

from box_sdk_gen.schemas.storage_policy_mini import StoragePolicyMini

from box_sdk_gen.box.errors import BoxSDKError


class StoragePolicy(StoragePolicyMini):
    def __init__(
        self,
        id: str,
        *,
        name: Optional[str] = None,
        type: StoragePolicyMiniTypeField = StoragePolicyMiniTypeField.STORAGE_POLICY,
        **kwargs
    ):
        """
        :param id: The unique identifier for this storage policy.
        :type id: str
        :param name: A descriptive name of the region., defaults to None
        :type name: Optional[str], optional
        :param type: The value will always be `storage_policy`., defaults to StoragePolicyMiniTypeField.STORAGE_POLICY
        :type type: StoragePolicyMiniTypeField, optional
        """
        super().__init__(id=id, type=type, **kwargs)
        self.name = name



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.folder_mini import FolderMini

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class FileRequestTypeField(str, Enum):
    FILE_REQUEST = 'file_request'


class FileRequestStatusField(str, Enum):
    ACTIVE = 'active'
    INACTIVE = 'inactive'


class FileRequest(BaseObject):
    _discriminator = 'type', {'file_request'}

    def __init__(
        self,
        id: str,
        folder: FolderMini,
        created_at: DateTime,
        updated_at: DateTime,
        *,
        type: FileRequestTypeField = FileRequestTypeField.FILE_REQUEST,
        title: Optional[str] = None,
        description: Optional[str] = None,
        status: Optional[FileRequestStatusField] = None,
        is_email_required: Optional[bool] = None,
        is_description_required: Optional[bool] = None,
        expires_at: Optional[DateTime] = None,
        url: Optional[str] = None,
        etag: Optional[str] = None,
        created_by: Optional[UserMini] = None,
        updated_by: Optional[UserMini] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for this file request.
                :type id: str
                :param created_at: The date and time when the file request was created.
                :type created_at: DateTime
                :param updated_at: The date and time when the file request was last updated.
                :type updated_at: DateTime
                :param type: The value will always be `file_request`., defaults to FileRequestTypeField.FILE_REQUEST
                :type type: FileRequestTypeField, optional
                :param title: The title of file request. This is shown
        in the Box UI to users uploading files.

        This defaults to title of the file request that was
        copied to create this file request., defaults to None
                :type title: Optional[str], optional
                :param description: The optional description of this file request. This is
        shown in the Box UI to users uploading files.

        This defaults to description of the file request that was
        copied to create this file request., defaults to None
                :type description: Optional[str], optional
                :param status: The status of the file request. This defaults
        to `active`.

        When the status is set to `inactive`, the file request
        will no longer accept new submissions, and any visitor
        to the file request URL will receive a `HTTP 404` status
        code.

        This defaults to status of file request that was
        copied to create this file request., defaults to None
                :type status: Optional[FileRequestStatusField], optional
                :param is_email_required: Whether a file request submitter is required to provide
        their email address.

        When this setting is set to true, the Box UI will show
        an email field on the file request form.

        This defaults to setting of file request that was
        copied to create this file request., defaults to None
                :type is_email_required: Optional[bool], optional
                :param is_description_required: Whether a file request submitter is required to provide
        a description of the files they are submitting.

        When this setting is set to true, the Box UI will show
        a description field on the file request form.

        This defaults to setting of file request that was
        copied to create this file request., defaults to None
                :type is_description_required: Optional[bool], optional
                :param expires_at: The date after which a file request will no longer accept new
        submissions.

        After this date, the `status` will automatically be set to
        `inactive`., defaults to None
                :type expires_at: Optional[DateTime], optional
                :param url: The generated URL for this file request. This URL can be shared
        with users to let them upload files to the associated folder., defaults to None
                :type url: Optional[str], optional
                :param etag: The HTTP `etag` of this file. This can be used in combination with
        the `If-Match` header when updating a file request. By providing that
        header, a change will only be performed on the  file request if the `etag`
        on the file request still matches the `etag` provided in the `If-Match`
        header., defaults to None
                :type etag: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.folder = folder
        self.created_at = created_at
        self.updated_at = updated_at
        self.type = type
        self.title = title
        self.description = description
        self.status = status
        self.is_email_required = is_email_required
        self.is_description_required = is_description_required
        self.expires_at = expires_at
        self.url = url
        self.etag = etag
        self.created_by = created_by
        self.updated_by = updated_by



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.collaboration import Collaboration

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData

from box_sdk_gen.internal.utils import DateTime


class UpdateCollaborationByIdRole(str, Enum):
    EDITOR = 'editor'
    VIEWER = 'viewer'
    PREVIEWER = 'previewer'
    UPLOADER = 'uploader'
    PREVIEWER_UPLOADER = 'previewer uploader'
    VIEWER_UPLOADER = 'viewer uploader'
    CO_OWNER = 'co-owner'
    OWNER = 'owner'


class UpdateCollaborationByIdStatus(str, Enum):
    PENDING = 'pending'
    ACCEPTED = 'accepted'
    REJECTED = 'rejected'


class CreateCollaborationItemTypeField(str, Enum):
    FILE = 'file'
    FOLDER = 'folder'


class CreateCollaborationItem(BaseObject):
    _discriminator = 'type', {'file', 'folder'}

    def __init__(
        self,
        *,
        type: Optional[CreateCollaborationItemTypeField] = None,
        id: Optional[str] = None,
        **kwargs
    ):
        """
                :param type: The type of the item that this collaboration will be
        granted access to., defaults to None
                :type type: Optional[CreateCollaborationItemTypeField], optional
                :param id: The ID of the item that will be granted access to., defaults to None
                :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id


class CreateCollaborationAccessibleByTypeField(str, Enum):
    USER = 'user'
    GROUP = 'group'


class CreateCollaborationAccessibleBy(BaseObject):
    _discriminator = 'type', {'user', 'group'}

    def __init__(
        self,
        type: CreateCollaborationAccessibleByTypeField,
        *,
        id: Optional[str] = None,
        login: Optional[str] = None,
        **kwargs
    ):
        """
                :param type: The type of collaborator to invite.
                :type type: CreateCollaborationAccessibleByTypeField
                :param id: The ID of the user or group.

        Alternatively, use `login` to specify a user by email
        address., defaults to None
                :type id: Optional[str], optional
                :param login: The email address of the user to grant access to the item.

        Alternatively, use `id` to specify a user by user ID., defaults to None
                :type login: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id
        self.login = login


class CreateCollaborationRole(str, Enum):
    EDITOR = 'editor'
    VIEWER = 'viewer'
    PREVIEWER = 'previewer'
    UPLOADER = 'uploader'
    PREVIEWER_UPLOADER = 'previewer uploader'
    VIEWER_UPLOADER = 'viewer uploader'
    CO_OWNER = 'co-owner'


class UserCollaborationsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_collaboration_by_id(
        self,
        collaboration_id: str,
        *,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Collaboration:
        """
                Retrieves a single collaboration.
                :param collaboration_id: The ID of the collaboration.
        Example: "1234"
                :type collaboration_id: str
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/collaborations/',
                        to_string(collaboration_id),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Collaboration)

    def update_collaboration_by_id(
        self,
        collaboration_id: str,
        *,
        role: Optional[UpdateCollaborationByIdRole] = None,
        status: Optional[UpdateCollaborationByIdStatus] = None,
        expires_at: Optional[DateTime] = None,
        can_view_path: Optional[bool] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Optional[Collaboration]:
        """
                Updates a collaboration.

                Can be used to change the owner of an item, or to


                accept collaboration invites. In case of accepting collaboration invite, role is not required.

                :param collaboration_id: The ID of the collaboration.
        Example: "1234"
                :type collaboration_id: str
                :param role: The level of access granted., defaults to None
                :type role: Optional[UpdateCollaborationByIdRole], optional
                :param status: Set the status of a `pending` collaboration invitation,
        effectively accepting, or rejecting the invite., defaults to None
                :type status: Optional[UpdateCollaborationByIdStatus], optional
                :param expires_at: Update the expiration date for the collaboration. At this date,
        the collaboration will be automatically removed from the item.

        This feature will only work if the **Automatically remove invited
        collaborators: Allow folder owners to extend the expiry date**
        setting has been enabled in the **Enterprise Settings**
        of the **Admin Console**. When the setting is not enabled,
        collaborations can not have an expiry date and a value for this
        field will be result in an error.

        Additionally, a collaboration can only be given an
        expiration if it was created after the **Automatically remove
        invited collaborator** setting was enabled., defaults to None
                :type expires_at: Optional[DateTime], optional
                :param can_view_path: Determines if the invited users can see the entire parent path to
        the associated folder. The user will not gain privileges in any
        parent folder and therefore can not see content the user is not
        collaborated on.

        Be aware that this meaningfully increases the time required to load the
        invitee's **All Files** page. We recommend you limit the number of
        collaborations with `can_view_path` enabled to 1,000 per user.

        Only an owner or co-owners can invite collaborators with a `can_view_path` of
        `true`. Only an owner can update `can_view_path` on existing collaborations.

        `can_view_path` can only be used for folder collaborations.

        When you delete a folder with `can_view_path=true`, collaborators may still see the parent path.
        For instructions on how to remove this, see
        [Even though a folder invited via can_view_path is deleted, the path remains displayed](https://support.box.com/hc/en-us/articles/37472814319891-Even-though-a-folder-invited-via-can-view-path-is-deleted-the-path-remains-displayed)., defaults to None
                :type can_view_path: Optional[bool], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'role': role,
            'status': status,
            'expires_at': expires_at,
            'can_view_path': can_view_path,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/collaborations/',
                        to_string(collaboration_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        if to_string(response.status) == '204':
            return None
        return deserialize(response.data, Collaboration)

    def delete_collaboration_by_id(
        self,
        collaboration_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes a single collaboration.
                :param collaboration_id: The ID of the collaboration.
        Example: "1234"
                :type collaboration_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/collaborations/',
                        to_string(collaboration_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def create_collaboration(
        self,
        item: CreateCollaborationItem,
        accessible_by: CreateCollaborationAccessibleBy,
        role: CreateCollaborationRole,
        *,
        is_access_only: Optional[bool] = None,
        can_view_path: Optional[bool] = None,
        expires_at: Optional[DateTime] = None,
        fields: Optional[List[str]] = None,
        notify: Optional[bool] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Collaboration:
        """
                Adds a collaboration for a single user or a single group to a file

                or folder.


                Collaborations can be created using email address, user IDs, or a


                group IDs.


                If a collaboration is being created with a group, access to


                this endpoint is dependent on the group's ability to be invited.


                If collaboration is in `pending` status, the following fields


                are redacted:


                - `login` and `name` are hidden if a collaboration was created


                using `user_id`,


                -  `name` is hidden if a collaboration was created using `login`.

                :param item: The item to attach the comment to.
                :type item: CreateCollaborationItem
                :param accessible_by: The user or group to give access to the item.
                :type accessible_by: CreateCollaborationAccessibleBy
                :param role: The level of access granted.
                :type role: CreateCollaborationRole
                :param is_access_only: If set to `true`, collaborators have access to
        shared items, but such items won't be visible in the
        All Files list. Additionally, collaborators won't
        see the path to the root folder for the
        shared item., defaults to None
                :type is_access_only: Optional[bool], optional
                :param can_view_path: Determines if the invited users can see the entire parent path to
        the associated folder. The user will not gain privileges in any
        parent folder and therefore can not see content the user is not
        collaborated on.

        Be aware that this meaningfully increases the time required to load the
        invitee's **All Files** page. We recommend you limit the number of
        collaborations with `can_view_path` enabled to 1,000 per user.

        Only an owner or co-owners can invite collaborators with a `can_view_path` of
        `true`. Only an owner can update `can_view_path` on existing collaborations.

        `can_view_path` can only be used for folder collaborations.

        When you delete a folder with `can_view_path=true`, collaborators may still see the parent path.
        For instructions on how to remove this, see
        [Even though a folder invited via can_view_path is deleted, the path remains displayed](https://support.box.com/hc/en-us/articles/37472814319891-Even-though-a-folder-invited-via-can-view-path-is-deleted-the-path-remains-displayed)., defaults to None
                :type can_view_path: Optional[bool], optional
                :param expires_at: Set the expiration date for the collaboration. At this date, the
        collaboration will be automatically removed from the item.

        This feature will only work if the **Automatically remove invited
        collaborators: Allow folder owners to extend the expiry date**
        setting has been enabled in the **Enterprise Settings**
        of the **Admin Console**. When the setting is not enabled,
        collaborations can not have an expiry date and a value for this
        field will be result in an error., defaults to None
                :type expires_at: Optional[DateTime], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param notify: Determines if users should receive email notification
        for the action performed., defaults to None
                :type notify: Optional[bool], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'item': item,
            'accessible_by': accessible_by,
            'role': role,
            'is_access_only': is_access_only,
            'can_view_path': can_view_path,
            'expires_at': expires_at,
        }
        query_params_map: Dict[str, str] = prepare_params(
            {'fields': to_string(fields), 'notify': to_string(notify)}
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/collaborations']
                ),
                method='POST',
                params=query_params_map,
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Collaboration)



from enum import Enum

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class ClassificationTemplateField(str, Enum):
    SECURITYCLASSIFICATION_6VMVOCHWUWO = 'securityClassification-6VMVochwUWo'


class Classification(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'box_security_classification_key': 'Box__Security__Classification__Key',
        'parent': '$parent',
        'template': '$template',
        'scope': '$scope',
        'version': '$version',
        'type': '$type',
        'type_version': '$typeVersion',
        'can_edit': '$canEdit',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'Box__Security__Classification__Key': 'box_security_classification_key',
        '$parent': 'parent',
        '$template': 'template',
        '$scope': 'scope',
        '$version': 'version',
        '$type': 'type',
        '$typeVersion': 'type_version',
        '$canEdit': 'can_edit',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        *,
        box_security_classification_key: Optional[str] = None,
        parent: Optional[str] = None,
        template: Optional[ClassificationTemplateField] = None,
        scope: Optional[str] = None,
        version: Optional[int] = None,
        type: Optional[str] = None,
        type_version: Optional[float] = None,
        can_edit: Optional[bool] = None,
        **kwargs
    ):
        """
                :param box_security_classification_key: The name of the classification applied to the item., defaults to None
                :type box_security_classification_key: Optional[str], optional
                :param parent: The identifier of the item that this metadata instance
        has been attached to. This combines the `type` and the `id`
        of the parent in the form `{type}_{id}`., defaults to None
                :type parent: Optional[str], optional
                :param template: The value will always be `securityClassification-6VMVochwUWo`., defaults to None
                :type template: Optional[ClassificationTemplateField], optional
                :param scope: The scope of the enterprise that this classification has been
        applied for.

        This will be in the format `enterprise_{enterprise_id}`., defaults to None
                :type scope: Optional[str], optional
                :param version: The version of the metadata instance. This version starts at 0 and
        increases every time a classification is updated., defaults to None
                :type version: Optional[int], optional
                :param type: The unique ID of this classification instance. This will be include
        the name of the classification template and a unique ID., defaults to None
                :type type: Optional[str], optional
                :param type_version: The version of the metadata template. This version starts at 0 and
        increases every time the template is updated. This is mostly for internal
        use., defaults to None
                :type type_version: Optional[float], optional
                :param can_edit: Whether an end user can change the classification., defaults to None
                :type can_edit: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.box_security_classification_key = box_security_classification_key
        self.parent = parent
        self.template = template
        self.scope = scope
        self.version = version
        self.type = type
        self.type_version = type_version
        self.can_edit = can_edit



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import Date


class SignRequestPrefillTag(BaseObject):
    def __init__(
        self,
        *,
        document_tag_id: Optional[str] = None,
        text_value: Optional[str] = None,
        checkbox_value: Optional[bool] = None,
        date_value: Optional[Date] = None,
        **kwargs
    ):
        """
        :param document_tag_id: This references the ID of a specific tag contained in a file of the signature request., defaults to None
        :type document_tag_id: Optional[str], optional
        :param text_value: Text prefill value., defaults to None
        :type text_value: Optional[str], optional
        :param checkbox_value: Checkbox prefill value., defaults to None
        :type checkbox_value: Optional[bool], optional
        :param date_value: Date prefill value., defaults to None
        :type date_value: Optional[Date], optional
        """
        super().__init__(**kwargs)
        self.document_tag_id = document_tag_id
        self.text_value = text_value
        self.checkbox_value = checkbox_value
        self.date_value = date_value



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class KeywordSkillCardTypeField(str, Enum):
    SKILL_CARD = 'skill_card'


class KeywordSkillCardSkillCardTypeField(str, Enum):
    KEYWORD = 'keyword'


class KeywordSkillCardSkillCardTitleField(BaseObject):
    def __init__(self, message: str, *, code: Optional[str] = None, **kwargs):
        """
        :param message: The actual title to show in the UI.
        :type message: str
        :param code: An optional identifier for the title., defaults to None
        :type code: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.message = message
        self.code = code


class KeywordSkillCardSkillTypeField(str, Enum):
    SERVICE = 'service'


class KeywordSkillCardSkillField(BaseObject):
    _discriminator = 'type', {'service'}

    def __init__(
        self,
        id: str,
        *,
        type: KeywordSkillCardSkillTypeField = KeywordSkillCardSkillTypeField.SERVICE,
        **kwargs
    ):
        """
                :param id: A custom identifier that represent the service that
        applied this metadata.
                :type id: str
                :param type: The value will always be `service`., defaults to KeywordSkillCardSkillTypeField.SERVICE
                :type type: KeywordSkillCardSkillTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class KeywordSkillCardInvocationTypeField(str, Enum):
    SKILL_INVOCATION = 'skill_invocation'


class KeywordSkillCardInvocationField(BaseObject):
    _discriminator = 'type', {'skill_invocation'}

    def __init__(
        self,
        id: str,
        *,
        type: KeywordSkillCardInvocationTypeField = KeywordSkillCardInvocationTypeField.SKILL_INVOCATION,
        **kwargs
    ):
        """
                :param id: A custom identifier that represent the instance of
        the service that applied this metadata. For example,
        if your `image-recognition-service` runs on multiple
        nodes, this field can be used to identify the ID of
        the node that was used to apply the metadata.
                :type id: str
                :param type: The value will always be `skill_invocation`., defaults to KeywordSkillCardInvocationTypeField.SKILL_INVOCATION
                :type type: KeywordSkillCardInvocationTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class KeywordSkillCardEntriesField(BaseObject):
    def __init__(self, *, text: Optional[str] = None, **kwargs):
        """
        :param text: The text of the keyword., defaults to None
        :type text: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.text = text


class KeywordSkillCard(BaseObject):
    _discriminator = 'skill_card_type', {'keyword'}

    def __init__(
        self,
        skill: KeywordSkillCardSkillField,
        invocation: KeywordSkillCardInvocationField,
        entries: List[KeywordSkillCardEntriesField],
        *,
        created_at: Optional[DateTime] = None,
        type: KeywordSkillCardTypeField = KeywordSkillCardTypeField.SKILL_CARD,
        skill_card_type: KeywordSkillCardSkillCardTypeField = KeywordSkillCardSkillCardTypeField.KEYWORD,
        skill_card_title: Optional[KeywordSkillCardSkillCardTitleField] = None,
        **kwargs
    ):
        """
                :param skill: The service that applied this metadata.
                :type skill: KeywordSkillCardSkillField
                :param invocation: The invocation of this service, used to track
        which instance of a service applied the metadata.
                :type invocation: KeywordSkillCardInvocationField
                :param entries: An list of entries in the metadata card.
                :type entries: List[KeywordSkillCardEntriesField]
                :param created_at: The optional date and time this card was created at., defaults to None
                :type created_at: Optional[DateTime], optional
                :param type: The value will always be `skill_card`., defaults to KeywordSkillCardTypeField.SKILL_CARD
                :type type: KeywordSkillCardTypeField, optional
                :param skill_card_type: The value will always be `keyword`., defaults to KeywordSkillCardSkillCardTypeField.KEYWORD
                :type skill_card_type: KeywordSkillCardSkillCardTypeField, optional
                :param skill_card_title: The title of the card., defaults to None
                :type skill_card_title: Optional[KeywordSkillCardSkillCardTitleField], optional
        """
        super().__init__(**kwargs)
        self.skill = skill
        self.invocation = invocation
        self.entries = entries
        self.created_at = created_at
        self.type = type
        self.skill_card_type = skill_card_type
        self.skill_card_title = skill_card_title



from enum import Enum

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.serialization.json import deserialize

from typing import List

from box_sdk_gen.internal.null_value import NullValue

from typing import Union

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.file_base import FileBase

from box_sdk_gen.schemas.sign_request_create_signer import SignRequestCreateSigner

from box_sdk_gen.schemas.folder_mini import FolderMini

from box_sdk_gen.schemas.sign_request_prefill_tag import SignRequestPrefillTag

from box_sdk_gen.schemas.sign_request import SignRequest

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.sign_request_cancel_request import SignRequestCancelRequest

from box_sdk_gen.schemas.sign_requests import SignRequests

from box_sdk_gen.schemas.sign_request_create_request import SignRequestCreateRequest

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class CreateSignRequestSignatureColor(str, Enum):
    BLUE = 'blue'
    BLACK = 'black'
    RED = 'red'


class SignRequestsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def cancel_sign_request(
        self,
        sign_request_id: str,
        *,
        reason: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> SignRequest:
        """
                Cancels a sign request.
                :param sign_request_id: The ID of the signature request.
        Example: "33243242"
                :type sign_request_id: str
                :param reason: An optional reason for cancelling the sign request., defaults to None
                :type reason: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'reason': reason}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/sign_requests/',
                        to_string(sign_request_id),
                        '/cancel',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body) if not request_body == None else None,
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, SignRequest)

    def resend_sign_request(
        self,
        sign_request_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Resends a signature request email to all outstanding signers.
                :param sign_request_id: The ID of the signature request.
        Example: "33243242"
                :type sign_request_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/sign_requests/',
                        to_string(sign_request_id),
                        '/resend',
                    ]
                ),
                method='POST',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def get_sign_request_by_id(
        self,
        sign_request_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> SignRequest:
        """
                Gets a sign request by ID.
                :param sign_request_id: The ID of the signature request.
        Example: "33243242"
                :type sign_request_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/sign_requests/',
                        to_string(sign_request_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, SignRequest)

    def get_sign_requests(
        self,
        *,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        senders: Optional[List[str]] = None,
        shared_requests: Optional[bool] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> SignRequests:
        """
                Gets signature requests created by a user. If the `sign_files` and/or

                `parent_folder` are deleted, the signature request will not return in the list.

                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param senders: A list of sender emails to filter the signature requests by sender.
        If provided, `shared_requests` must be set to `true`., defaults to None
                :type senders: Optional[List[str]], optional
                :param shared_requests: If set to `true`, only includes requests that user is not an owner,
        but user is a collaborator. Collaborator access is determined by the
        user access level of the sign files of the request.
        Default is `false`. Must be set to `true` if `senders` are provided., defaults to None
                :type shared_requests: Optional[bool], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'marker': to_string(marker),
                'limit': to_string(limit),
                'senders': to_string(senders),
                'shared_requests': to_string(shared_requests),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/sign_requests']
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, SignRequests)

    def create_sign_request(
        self,
        signers: List[SignRequestCreateSigner],
        *,
        source_files: Union[Optional[List[FileBase]], NullValue] = None,
        signature_color: Union[
            Optional[CreateSignRequestSignatureColor], NullValue
        ] = None,
        parent_folder: Optional[FolderMini] = None,
        is_document_preparation_needed: Optional[bool] = None,
        redirect_url: Union[Optional[str], NullValue] = None,
        declined_redirect_url: Union[Optional[str], NullValue] = None,
        are_text_signatures_enabled: Optional[bool] = None,
        email_subject: Union[Optional[str], NullValue] = None,
        email_message: Union[Optional[str], NullValue] = None,
        are_reminders_enabled: Optional[bool] = None,
        name: Optional[str] = None,
        prefill_tags: Optional[List[SignRequestPrefillTag]] = None,
        days_valid: Union[Optional[int], NullValue] = None,
        external_id: Union[Optional[str], NullValue] = None,
        template_id: Union[Optional[str], NullValue] = None,
        external_system_name: Union[Optional[str], NullValue] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> SignRequest:
        """
                Creates a signature request. This involves preparing a document for signing and

                sending the signature request to signers.

                :param signers: Array of signers for the signature request. 35 is the
        max number of signers permitted.

        **Note**: It may happen that some signers belong to conflicting [segments](https://developer.box.com/reference/resources/shield-information-barrier-segment-member) (user groups).
        This means that due to the security policies, users are assigned to segments to prevent exchanges or communication that could lead to ethical conflicts.
        In such a case, an attempt to send the sign request will result in an error.

        Read more about [segments and ethical walls](https://support.box.com/hc/en-us/articles/9920431507603-Understanding-Information-Barriers#h_01GFVJEHQA06N7XEZ4GCZ9GFAQ).
                :type signers: List[SignRequestCreateSigner]
                :param source_files: List of files to create a signing document from. This is currently limited to ten files. Only the ID and type fields are required for each file., defaults to None
                :type source_files: Union[Optional[List[FileBase]], NullValue], optional
                :param signature_color: Force a specific color for the signature (blue, black, or red)., defaults to None
                :type signature_color: Union[Optional[CreateSignRequestSignatureColor], NullValue], optional
                :param is_document_preparation_needed: Indicates if the sender should receive a `prepare_url` in the response to complete document preparation using the UI., defaults to None
                :type is_document_preparation_needed: Optional[bool], optional
                :param redirect_url: When specified, the signature request will be redirected to this url when a document is signed., defaults to None
                :type redirect_url: Union[Optional[str], NullValue], optional
                :param declined_redirect_url: The uri that a signer will be redirected to after declining to sign a document., defaults to None
                :type declined_redirect_url: Union[Optional[str], NullValue], optional
                :param are_text_signatures_enabled: Disables the usage of signatures generated by typing (text)., defaults to None
                :type are_text_signatures_enabled: Optional[bool], optional
                :param email_subject: Subject of sign request email. This is cleaned by sign request. If this field is not passed, a default subject will be used., defaults to None
                :type email_subject: Union[Optional[str], NullValue], optional
                :param email_message: Message to include in sign request email. The field is cleaned through sanitization of specific characters. However, some html tags are allowed. Links included in the message are also converted to hyperlinks in the email. The message may contain the following html tags including `a`, `abbr`, `acronym`, `b`, `blockquote`, `code`, `em`, `i`, `ul`, `li`, `ol`, and `strong`. Be aware that when the text to html ratio is too high, the email may end up in spam filters. Custom styles on these tags are not allowed. If this field is not passed, a default message will be used., defaults to None
                :type email_message: Union[Optional[str], NullValue], optional
                :param are_reminders_enabled: Reminds signers to sign a document on day 3, 8, 13 and 18. Reminders are only sent to outstanding signers., defaults to None
                :type are_reminders_enabled: Optional[bool], optional
                :param name: Name of the signature request., defaults to None
                :type name: Optional[str], optional
                :param prefill_tags: When a document contains sign-related tags in the content, you can prefill them using this `prefill_tags` by referencing the 'id' of the tag as the `external_id` field of the prefill tag., defaults to None
                :type prefill_tags: Optional[List[SignRequestPrefillTag]], optional
                :param days_valid: Set the number of days after which the created signature request will automatically expire if not completed. By default, we do not apply any expiration date on signature requests, and the signature request does not expire., defaults to None
                :type days_valid: Union[Optional[int], NullValue], optional
                :param external_id: This can be used to reference an ID in an external system that the sign request is related to., defaults to None
                :type external_id: Union[Optional[str], NullValue], optional
                :param template_id: When a signature request is created from a template this field will indicate the id of that template., defaults to None
                :type template_id: Union[Optional[str], NullValue], optional
                :param external_system_name: Used as an optional system name to appear in the signature log next to the signers who have been assigned the `embed_url_external_id`., defaults to None
                :type external_system_name: Union[Optional[str], NullValue], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'source_files': source_files,
            'signature_color': signature_color,
            'signers': signers,
            'parent_folder': parent_folder,
            'is_document_preparation_needed': is_document_preparation_needed,
            'redirect_url': redirect_url,
            'declined_redirect_url': declined_redirect_url,
            'are_text_signatures_enabled': are_text_signatures_enabled,
            'email_subject': email_subject,
            'email_message': email_message,
            'are_reminders_enabled': are_reminders_enabled,
            'name': name,
            'prefill_tags': prefill_tags,
            'days_valid': days_valid,
            'external_id': external_id,
            'template_id': template_id,
            'external_system_name': external_system_name,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/sign_requests']
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, SignRequest)



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class SignRequestSignerInputZipValidationValidationTypeField(str, Enum):
    ZIP = 'zip'


class SignRequestSignerInputZipValidation(BaseObject):
    def __init__(
        self,
        *,
        validation_type: SignRequestSignerInputZipValidationValidationTypeField = SignRequestSignerInputZipValidationValidationTypeField.ZIP,
        **kwargs
    ):
        """
        :param validation_type: Validates that the text input is a ZIP code., defaults to SignRequestSignerInputZipValidationValidationTypeField.ZIP
        :type validation_type: SignRequestSignerInputZipValidationValidationTypeField, optional
        """
        super().__init__(**kwargs)
        self.validation_type = validation_type



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.file_mini import FileMini

from box_sdk_gen.schemas.task_assignments import TaskAssignments

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class TaskTypeField(str, Enum):
    TASK = 'task'


class TaskActionField(str, Enum):
    REVIEW = 'review'
    COMPLETE = 'complete'


class TaskCompletionRuleField(str, Enum):
    ALL_ASSIGNEES = 'all_assignees'
    ANY_ASSIGNEE = 'any_assignee'


class Task(BaseObject):
    _discriminator = 'type', {'task'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[TaskTypeField] = None,
        item: Optional[FileMini] = None,
        due_at: Optional[DateTime] = None,
        action: Optional[TaskActionField] = None,
        message: Optional[str] = None,
        task_assignment_collection: Optional[TaskAssignments] = None,
        is_completed: Optional[bool] = None,
        created_by: Optional[UserMini] = None,
        created_at: Optional[DateTime] = None,
        completion_rule: Optional[TaskCompletionRuleField] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for this task., defaults to None
                :type id: Optional[str], optional
                :param type: The value will always be `task`., defaults to None
                :type type: Optional[TaskTypeField], optional
                :param due_at: When the task is due., defaults to None
                :type due_at: Optional[DateTime], optional
                :param action: The type of task the task assignee will be prompted to
        perform., defaults to None
                :type action: Optional[TaskActionField], optional
                :param message: A message that will be included with the task., defaults to None
                :type message: Optional[str], optional
                :param is_completed: Whether the task has been completed., defaults to None
                :type is_completed: Optional[bool], optional
                :param created_at: When the task object was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param completion_rule: Defines which assignees need to complete this task before the task
        is considered completed.

        * `all_assignees` requires all assignees to review or
        approve the task in order for it to be considered completed.
        * `any_assignee` accepts any one assignee to review or
        approve the task in order for it to be considered completed., defaults to None
                :type completion_rule: Optional[TaskCompletionRuleField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.item = item
        self.due_at = due_at
        self.action = action
        self.message = message
        self.task_assignment_collection = task_assignment_collection
        self.is_completed = is_completed
        self.created_by = created_by
        self.created_at = created_at
        self.completion_rule = completion_rule



from typing import Union

from box_sdk_gen.schemas.file import File

from box_sdk_gen.schemas.folder import Folder

from box_sdk_gen.schemas.web_link import WebLink

from box_sdk_gen.box.errors import BoxSDKError

CollaborationItem = Union[File, Folder, WebLink]



from enum import Enum

from typing import Optional

from box_sdk_gen.schemas.shield_information_barrier_report_base import (
    ShieldInformationBarrierReportBaseTypeField,
)

from box_sdk_gen.schemas.shield_information_barrier_report_base import (
    ShieldInformationBarrierReportBase,
)

from box_sdk_gen.schemas.shield_information_barrier_reference import (
    ShieldInformationBarrierReference,
)

from box_sdk_gen.schemas.shield_information_barrier_report_details import (
    ShieldInformationBarrierReportDetails,
)

from box_sdk_gen.schemas.user_base import UserBase

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class ShieldInformationBarrierReportStatusField(str, Enum):
    PENDING = 'pending'
    ERROR = 'error'
    DONE = 'done'
    CANCELLED = 'cancelled'


class ShieldInformationBarrierReport(ShieldInformationBarrierReportBase):
    def __init__(
        self,
        *,
        shield_information_barrier: Optional[ShieldInformationBarrierReference] = None,
        status: Optional[ShieldInformationBarrierReportStatusField] = None,
        details: Optional[ShieldInformationBarrierReportDetails] = None,
        created_at: Optional[DateTime] = None,
        created_by: Optional[UserBase] = None,
        updated_at: Optional[DateTime] = None,
        id: Optional[str] = None,
        type: Optional[ShieldInformationBarrierReportBaseTypeField] = None,
        **kwargs
    ):
        """
                :param status: Status of the shield information report., defaults to None
                :type status: Optional[ShieldInformationBarrierReportStatusField], optional
                :param created_at: ISO date time string when this
        shield information barrier report object was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param updated_at: ISO date time string when this
        shield information barrier report was updated., defaults to None
                :type updated_at: Optional[DateTime], optional
                :param id: The unique identifier for the shield information barrier report., defaults to None
                :type id: Optional[str], optional
                :param type: The type of the shield information barrier report., defaults to None
                :type type: Optional[ShieldInformationBarrierReportBaseTypeField], optional
        """
        super().__init__(id=id, type=type, **kwargs)
        self.shield_information_barrier = shield_information_barrier
        self.status = status
        self.details = details
        self.created_at = created_at
        self.created_by = created_by
        self.updated_at = updated_at
